@@ -41,9 +41,11 @@ __all__ = (
     "CreateLifecyclePolicyResponseTypeDef",
     "CreateRuleTypeDef",
     "CrossRegionCopyActionTypeDef",
+    "CrossRegionCopyDeprecateRuleTypeDef",
     "CrossRegionCopyRetainRuleTypeDef",
     "CrossRegionCopyRuleTypeDef",
     "DeleteLifecyclePolicyRequestRequestTypeDef",
+    "DeprecateRuleTypeDef",
     "EncryptionConfigurationTypeDef",
     "EventParametersTypeDef",
     "EventSourceTypeDef",
@@ -143,6 +145,15 @@ class CrossRegionCopyActionTypeDef(
     pass
 
 
+CrossRegionCopyDeprecateRuleTypeDef = TypedDict(
+    "CrossRegionCopyDeprecateRuleTypeDef",
+    {
+        "Interval": int,
+        "IntervalUnit": RetentionIntervalUnitValuesType,
+    },
+    total=False,
+)
+
 CrossRegionCopyRetainRuleTypeDef = TypedDict(
     "CrossRegionCopyRetainRuleTypeDef",
     {
@@ -166,6 +177,7 @@ _OptionalCrossRegionCopyRuleTypeDef = TypedDict(
         "CmkArn": str,
         "CopyTags": bool,
         "RetainRule": "CrossRegionCopyRetainRuleTypeDef",
+        "DeprecateRule": "CrossRegionCopyDeprecateRuleTypeDef",
     },
     total=False,
 )
@@ -184,6 +196,16 @@ DeleteLifecyclePolicyRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeprecateRuleTypeDef = TypedDict(
+    "DeprecateRuleTypeDef",
+    {
+        "Count": int,
+        "Interval": int,
+        "IntervalUnit": RetentionIntervalUnitValuesType,
+    },
+    total=False,
+)
+
 _RequiredEncryptionConfigurationTypeDef = TypedDict(
     "_RequiredEncryptionConfigurationTypeDef",
     {
@@ -390,6 +412,7 @@ ScheduleTypeDef = TypedDict(
         "FastRestoreRule": "FastRestoreRuleTypeDef",
         "CrossRegionCopyRules": List["CrossRegionCopyRuleTypeDef"],
         "ShareRules": List["ShareRuleTypeDef"],
+        "DeprecateRule": "DeprecateRuleTypeDef",
     },
     total=False,
 )
